@@ -9,13 +9,14 @@ from ..config import CONFIG
 
 THE_QUERY = \
 """
-SELECT tags.distance_cm as distance,
+SELECT tags.distance,
        zones.name as zone_name,
        tags.name as tag_name,
        tags.type as tag_type,
        last_seen,
        tags.id as tag_id,
-       zone_id
+       zone_id,
+       alarm_active
 FROM tags
 LEFT JOIN zones on zones.id = zone_id
 ORDER BY tags.id DESC
@@ -23,13 +24,14 @@ ORDER BY tags.id DESC
 
 THE_TYPE_QUERY = \
 """
-SELECT tags.distance_cm as distance,
+SELECT tags.distance,
        zones.name as zone_name,
        tags.name as tag_name,
        tags.type as tag_type,
        last_seen,
        tags.id as tag_id,
-       zone_id
+       zone_id,
+       alarm_active
 FROM tags
 LEFT JOIN zones on zones.id = zone_id
 WHERE tags.type = $1
@@ -38,13 +40,14 @@ ORDER BY tags.id DESC
 
 THE_GROUP_QUERY = \
 """
-SELECT tags.distance_cm as distance,
+SELECT tags.distance,
        zones.name as zone_name,
        tags.name as tag_name,
        tags.type as tag_type,
        last_seen,
        tags.id as tag_id,
-       zone_id
+       zone_id,
+       alarm_active
 FROM tags
 LEFT JOIN zones on zones.id = zone_id
 WHERE tags.group_id = $1
@@ -98,16 +101,22 @@ class ProximityView(web.View, CorsViewMixin):
 
 
 async def proximity_task(pool):
-    query = """UPDATE tags SET zone_id = cf.zone_id, distance_cm = distance FROM
+    query = """UPDATE tags SET zone_id = cf.zone_id, distance = cf.distance FROM
 (SELECT DISTINCT ON (upper.tag_id)
-    coalesce(anchor_dist, upper.distance_cm) as distance,
+    coalesce(anchor_dist, upper.distance) as distance,
     upper.tag_id, tags.zone_id from log upper
 LEFT JOIN tags on tags.id = upper.anchor_id
 WHERE ts > tags.last_seen - interval '10s'
 ORDER BY upper.tag_id, distance, upper.ts DESC) as cf
 WHERE tags.id = cf.tag_id;
 """
+    period = CONFIG['LOCATION_UPDATE_MS'] / 1000
+    count = 0
+
     while True:
         async with pool.acquire() as conn:
             await conn.execute(query)
-        await asyncio.sleep(CONFIG['LOCATION_UPDATE_MS'] / 1000)
+            count += 1
+            if count % 60 == 0:  # Once per minute
+                await conn.execute("DELETE FROM log WHERE ts < current_timestamp - interval '5m'")
+            await asyncio.sleep(period)
